# Copyright (C) 2023 Bootloader.  All rights reserved.
#
# This software is the confidential and proprietary information of
# Bootloader or one of its subsidiaries.  You shall not disclose this
# confidential information and shall use it only in accordance with the
# terms of the license agreement or other applicable agreement you
# entered into with Bootloader.
#
# BOOTLOADER MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE
# SUITABILITY OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT
# NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR
# A PARTICULAR PURPOSE, OR NON-INFRINGEMENT.  BOOTLOADER SHALL NOT BE
# LIABLE FOR ANY LOSSES OR DAMAGES SUFFERED BY LICENSEE AS A RESULT OF
# USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.

from majormode.perseus.model.enum import Enum


AssetTypes = Enum(
    'AbilitySystemComponent',
    'Actor',
    'ActorComponent',
    'AIController',
    'AimOffsetBlendSpace',
    'AimOffsetBlendSpace1D',
    'AIPerceptionComponent',
    'AnimationModifier',
    'AnimBlueprint',
    'AnimLayerInterface',
    'AnimComposite',
    'AnimInstance',
    'AnimMontage',
    'AnimSequence',
    'AnimationSharingSetup',
    'ApplicationLifecycleComponent',
    'AtmosphericFog',
    'BehaviorTree',
    'BlackboardData',
    'BlendSpace',
    'BlendSpace1D',
    'BlockingVolume',
    'Blueprint',
    'BlueprintFunctionLibrary',
    'BlueprintGeneratedClass',
    'BlueprintInterface',
    'BlueprintMacroLibrary',
    'BoxReflectionCapture',
    'ButtonStyleAsset',
    'CableActor',
    'CableComponent',
    'CameraActor',
    'CameraAnim',
    'CameraBlockingVolume',
    'Character',
    'CharacterMovementComponent',
    'Class',
    'CullDistanceVolume',
    'CurveBase',
    'DataAsset',
    'DataTable',
    'DecalActor',
    'Default',
    'DefaultPawn',
    'DialogueWave',
    'DialogueVoice',
    'DirectionalLight',
    'DirectionalLightMovable',
    'DirectionalLightStatic',
    'DirectionalLightStationary',
    'DocumentationActor',
    'EditorTutorial',
    'EnvQuery',
    'ExponentialHeightFog',
    'FileMediaSource',
    'Font',
    'FontFace',
    'ForceFeedbackEffect',
    'GameModeBase',
    'GameStateBase',
    'HUD',
    'Interface',
    'InterpData',
    'KillZVolume',
    'Landscape',
    'LandscapeBlueprintBrushBase',
    'LevelBounds',
    'LevelSequence',
    'LevelStreamingVolume',
    'LightmassCharacterIndirectDetailVolume',
    'VolumetricLightmapDensityVolume',
    'LightmassImportanceVolume',
    'MassiveLODOverrideVolume',
    'Material',
    'MaterialFunction',
    'MaterialInstanceActor',
    'MaterialInstanceConstant',
    'MaterialParameterCollection',
    'MediaPlayer',
    'MediaTexture',
    'LevelSequenceActor',
    'MultiFont',
    'NavLinkProxy',
    'NavMeshBoundsVolume',
    'NavModifierComponent',
    'NavModifierVolume',
    'Note',
    'ObjectLibrary',
    'PainCausingVolume',
    'ParticleSystem',
    'Pawn',
    'PawnNoiseEmitterComponent',
    'PawnSensingComponent',
    'PhysicalMaterial',
    'PhysicsAsset',
    'PhysicsConstraintActor',
    'PhysicsConstraintComponent',
    'PhysicsHandleComponent',
    'PhysicsThruster',
    'PhysicsThrusterComponent',
    'PhysicsVolume',
    'PlaneReflectionCapture',
    'PlatformMediaSource',
    'PlayerController',
    'PlayerStart',
    'PointLight',
    'PoseAsset',
    'PostProcessVolume',
    'PrecomputedVisibilityOverrideVolume',
    'PrecomputedVisibilityVolume',
    'ProceduralFoliageVolume',
    'ProceduralFoliageBlockingVolume',
    'ProjectileMovementComponent',
    'RadialForceActor',
    'RadialForceComponent',
    'ReflectionCapture',
    'RotatingMovementComponent',
    'SceneCapture2D',
    'SceneCaptureCube',
    'SceneComponent',
    'SkyLight',
    'SkyLightComponent',
    'SkyAtmosphere',
    'VolumetricCloud',
    'SkeletalMesh',
    'Skeleton',
    'SlateBrushAsset',
    'SlateWidgetStyleAsset',
    'StringTable',
    'SphereReflectionCapture',
    'SpotLight',
    'SpotLightMovable',
    'SpotLightStatic',
    'SpotLightStationary',
    'SpringArmComponent',
    'StaticMesh',
    'StreamMediaSource',
    'SubsurfaceProfile',
    'TargetPoint',
    'TextRenderActor',
    'Texture2D',
    'TextureRenderTarget2D',
    'TextureRenderTargetCube',
    'TriggerBase',
    'TriggerBox',
    'TriggerCapsule',
    'TriggerSphere',
    'TriggerVolume',
    'TouchInterface',
    'UserDefinedCaptureProtocol',
    'UserDefinedEnum',
    'UserDefinedStruct',
    'UserWidget',
    'WidgetBlueprint',
    'WidgetBlueprintGeneratedClass',
    'WindDirectionalSource',
    'World',
    'Cube',
    'Sphere',
    'Cylinder',
    'Cone',
    'Plane',
    'CineCameraActor',
    'CameraRig_Crane',
    'CameraRig_Rail',
    'FoliageType_Actor',
    'FoundationActor',
)
